<?php

add_action( 'after_setup_theme', 'oenology_setup', 10 );

if ( ! function_exists( 'oenology_setup' ) ):

	function oenology_setup() {

		/*****************************************************************************************
		* Add theme support for various WordPress features
		*******************************************************************************************/

		// Automatically add RSS feed links to document header (since WP 2.9.0)
		add_theme_support('automatic-feed-links');

		// Post Thumbnails (since WP 2.9.0)
		add_theme_support('post-thumbnails'); 

		// Custom Backgrounds (since WP 3.0.0)
		add_custom_background();

		// Custom Header Image (since WP 3.0.0)
		add_custom_image_header( 'oenology_header_style', 'oenology_admin_header_style' );

		// Custom WYSIWIG Editor Style (since WP 3.0.0)
		add_editor_style();

		// Post Formats (since WP 3.1.0)
		function oenology_get_post_formats() {
			$postformats = array( 'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video' );
			return $postformats;
		}
		$postformats = oenology_get_post_formats();
		add_theme_support( 'post-formats', $postformats );
		

		/*****************************************************************************************
		* Define content_width, to keep images from overflowing.
		*******************************************************************************************/

		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 640;
		}
		

		/*****************************************************************************************
		* Define Custom Image sizes (since WordPress 2.9)
		*******************************************************************************************/
		
		set_post_thumbnail_size( 150, 150, true ); // default dimensions for "thumbnail" image size
		add_image_size( 'post-title-thumbnail', 55, 55, true ); // Post Title thumbnail size (55px x 55px)
		add_image_size( 'attachment-nav-thumbnail', 45, 45, true ); // Gallery Navigation image thumbnail size (55px x 55px)


		/*****************************************************************************************
		* Define Custom Headers (since WordPress 3.0)
		*******************************************************************************************/
		
		// Default header image to use
		//define('HEADER_IMAGE', get_template_directory_uri() . '/images/headers/pxwhite.jpg'); 
		// Width to which WordPress will crop uploaded header images
		define( 'HEADER_IMAGE_WIDTH', apply_filters( 'oenology_header_image_width', 1000 ) ); 
		// Height to which WordPress will crop uploaded header images
		define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'oenology_header_image_height', 198 ) ); 
		// Allow text inside the header image.
		define( 'NO_HEADER_TEXT', false );
			
		$headertextcolor = ( get_header_textcolor() ? get_header_textcolor() : false );
		if ( ! $headertextcolor ) {
			$colorscheme = oenology_get_color_scheme();
			
			if ( 'light' == $colorscheme ) {
				$headertextcolor = '666666';
			} elseif ( 'dark' == $colorscheme ) {
				$headertextcolor = 'dddddd';
			}
		}
		define( 'HEADER_TEXTCOLOR', $headertextcolor );

		// Add a way for the custom header to be styled in the admin panel that controls
		// custom headers. See oenology_admin_header_style(), below.
	
		// Default custom headers packaged with the theme. 
		// %s is a placeholder for the theme template directory URI.
		// Auto-magically registers the headers included with TwentyTen if it is installed
		if ( file_exists( get_theme_root() . '/twentyten/style.css' ) ) {
			register_default_headers( array(
				'berries' => array(
					'url' => '%s/../twentyten/images/headers/berries.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/berries-thumbnail.jpg',
					'description' => 'Berries'
				),
				'cherryblossom' => array(
					'url' => '%s/../twentyten/images/headers/cherryblossoms.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/cherryblossoms-thumbnail.jpg',
					'description' => 'Cherry Blossoms'
				),
				'concave' => array(
					'url' => '%s/../twentyten/images/headers/concave.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/concave-thumbnail.jpg',
					'description' => 'Concave'
				),
				'fern' => array(
					'url' => '%s/../twentyten/images/headers/fern.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/fern-thumbnail.jpg',
					'description' => 'Fern'
				),
				'forestfloor' => array(
					'url' => '%s/../twentyten/images/headers/forestfloor.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/forestfloor-thumbnail.jpg',
					'description' => 'Forest Floor'
				),
				'inkwell' => array(
					'url' => '%s/../twentyten/images/headers/inkwell.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/inkwell-thumbnail.jpg',
					'description' => 'Inkwell', 'oenology'
				),
				'path' => array(
					'url' => '%s/../twentyten/images/headers/path.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/path-thumbnail.jpg',
					'description' => 'Path'
				),
				'sunset' => array(
					'url' => '%s/../twentyten/images/headers/sunset.jpg',
					'thumbnail_url' => '%s/../twentyten/images/headers/sunset-thumbnail.jpg',
					'description' => 'Sunset'
				)
			) );
		}
	
		if ( ! function_exists( 'oenology_header_style' ) ) :

			function oenology_header_style() { ?>
			
<style type="text/css">
/* Sets header image as background for div#header */
			<?php if ( get_header_image() ) { ?>
#header {
	background:url('<?php header_image(); ?>') no-repeat center top;
	overflow: hidden;
}
#site-header-text {
	background: rgba(0, 0, 0, 0.2);
}
.navmenu,
.nav-header {
	background: rgba(0, 0, 0, 0.2);
}
			<?php } ?>
/* Sets text color for div#header p and div */
			<?php if ( get_header_textcolor() ) { ?>
#site-header-text {
	color:#<?php header_textcolor(); ?>;
}
			<?php }
			 
				$oenology_options = get_option('theme_oenology_options');
				if ( 'above' == $oenology_options['header_nav_menu_position'] ) {
					if ( get_header_image() ) { ?>
#nav,
.navmenu,
.nav-header {
	background-color: rgba(0, 0, 0, 0.2);
}
					<?php } ?>
.navmenu li {
	padding-top: 1px;
}
				<?php }
			?>
			</style>
			<?php
			}

		endif;

		if ( ! function_exists( 'oenology_admin_header_style' ) ) :

			function oenology_admin_header_style() {
			?>
<style type="text/css">
#headimg {
	width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
	height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
	text-align: center;
}
#headimg h1,
#headimg div {
	border:0;
}
#headimg h1 {
  clear:both;
  width:100%;
  padding-top:10px;
  padding-bottom:10px;
  font-size: 28pt;
  line-height:1.5em;
  letter-spacing: 0.2em;
  font-weight:normal;
  text-transform:none;
  font-family: slab-serif, serif;
}
#headimg h1 a {
	text-decoration: none;
}
#headimg div {
  padding-top:0px;
  padding-bottom:10px;
  max-width:100%;
  text-align:center;
  font-size: 13pt;
  line-height:2.0em;
  letter-spacing:0em;
  font-family: 'Nimbus Roman No9 L', 'Times New Roman', serif;
}  
</style>
			<?php
			}
	
		endif;

		/*****************************************************************************************
		* Define Nav Menus (since WordPress 3.0)
		*******************************************************************************************/

		// This theme uses wp_nav_menu() in two locations: main site navigation, and left-colum page navigation.
		register_nav_menus( array(
			'nav-header' => 'Header Navigation',
			'nav-sidebar' => 'Sidebar Navigation',
		) );

	
	} // function oenology_setup()

endif; // function_exists('oenology_setup')

/*
Reference:
=============================================================================
The following functions, tags, and hooks are used (or referenced) in this Theme template file:


***********************
oenology_setup()
----------------------------------
oenology_setup() is a custom Theme function.
Codex reference: N/A
Defined in: functions.php

oenology_setup() is used to define and setup all of the custom Theme features, including
Theme support for optional WordPress features. This function is designed to be over-ridden
by a Child Theme, if necessary.

oenology_setup() hooks into the after_setup_theme action hook


=============================================================================
*/
?>